@@ -9,6 +9,10 @@ class AtCoder(ServiceParser):
     def description(self):
         return 'AtCoder (https://atcoder.jp/)'
 
+    @property
+    def aliases(self):
+        return ['atcoder', 'atc']
+
     @property
     def login_page(self):
         return "https://atcoder.jp/login"
