@@ -7,6 +7,10 @@ class Usaco(ServiceParser):
     def description(self):
         return 'Usaco (https://usaco.org/)'
 
+    @property
+    def aliases(self):
+        return ['usaco']
+
     @property
     def login_page(self):
         return "http://www.usaco.org/"
