@@ -7,8 +7,12 @@ class InitParser(BaseParser):
     def description(self):
         return 'Initialize configs'
 
-    def __init__(self, alias=None):
-        super().__init__(alias)
+    @property
+    def aliases(self):
+        return ['init']
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
         self._confman = ConfigManager()
         for option in self._confman.options:
             self._argparser.add_argument(
